/*
 *  _____ _______         _                      _
 * |_   _|__   __|       | |                    | |
 *   | |    | |_ __   ___| |___      _____  _ __| | __  ___ ____
 *   | |    | | '_ \ / _ \ __\ \ /\ / / _ \| '__| |/ / / __|_  /
 *  _| |_   | | | | |  __/ |_ \ V  V / (_) | |  |   < | (__ / /
 * |_____|  |_|_| |_|\___|\__| \_/\_/ \___/|_|  |_|\_(_)___/___|
 *                                _
 *              ___ ___ ___ _____|_|_ _ _____
 *             | . |  _| -_|     | | | |     |  LICENCE
 *             |  _|_| |___|_|_|_|_|___|_|_|_|
 *             |_|
 *
 *   PROGRAMOVÁNÍ  <>  DESIGN  <>  PRÁCE/PODNIKÁNÍ  <>  HW A SW
 *
 * Tento zdrojový kód je součástí výukových seriálů na
 * IT sociální síti WWW.ITNETWORK.CZ
 *
 * Kód spadá pod licenci prémiového obsahu a vznikl díky podpoře
 * našich členů. Je určen pouze pro osobní užití a nesmí být šířen.
 * Více informací na http://www.itnetwork.cz/licence
 */

class Clovek {
    private jmeno: string;
    private vek: number;

    protected vManzelstvi: Clovek;
    protected prijmeni: string;

    public constructor(jmeno: string, prijmeni: string, vek: number) {
        this.jmeno = jmeno;
        this.prijmeni = prijmeni;
        this.vek = vek;
    }

    public getJmeno(): string {
        return this.jmeno;
    }

    public getPrijmeni(): string {
        return this.prijmeni;
    }

    public getVek(): number {
        return this.vek;
    }

    public prejmenovat(noveJmeno: string): void {
        this.jmeno = noveJmeno;
    }

    public vratVypisCloveka(): string {
        return this.jmeno + " " + this.prijmeni + ", " + this.vek + " let.";
    }

    public static svatba(zenich: Muz, nevesta: Zena) {
        zenich.ozenit(nevesta);
        nevesta.vdat(zenich);
    }
}

class Muz extends Clovek {
    private zenaty: boolean;

    public constructor(jmeno: string, prijmeni: string, vek: number, zenaty: boolean) {
        super(jmeno, prijmeni, vek);
        this.zenaty = zenaty;
    }

    public vratVypisCloveka(): string {
        return this.getJmeno() + " " + this.prijmeni + ", " + this.getVek() + " let. Ženatý: " + this.zenaty + "<br>";
    }

    public ozenit(nevesta: Zena) {
        this.zenaty = true;
        this.vManzelstvi = nevesta;
    }
}

class Zena extends Clovek {
    private tehotna: boolean;
    private pocetPorodu: number;
    private vdana: boolean;

    public constructor(jmeno: string, prijmeni: string, vek: number, vdana: boolean = false, tehotna: boolean = false, pocetPorodu: number = 0) {
        super(jmeno, prijmeni, vek);
        this.tehotna = tehotna;
        this.pocetPorodu = pocetPorodu;
        this.vdana = vdana;
    }

    public zmenaPrijmeni(novePrijmeni: string): void {
        this.prijmeni = novePrijmeni;
    }

    public vdat(zenich: Muz) {
        this.vdana = true;
        this.vManzelstvi = zenich;
        this.zmenaPrijmeni(zenich.getPrijmeni());
    }

    public porodit(pocet: number = 1) {
        this.pocetPorodu += pocet;
    }

    public vratVypisCloveka(): string {
        let vypis = this.getJmeno() + " " + this.prijmeni + ", " + this.getVek() + " let. Vdaná: " + this.vdana + ", Porodů: " + this.pocetPorodu + "<br>";
        if (this.vdana) {
            vypis += "Vdaná za: " + this.vManzelstvi.getJmeno() + " " + this.vManzelstvi.getPrijmeni();
        }

        return vypis;
    }
}

let lucie = new Zena("Lucie", "Novohradská", 38, false, false, 0);
let pepa = new Muz("Pepa", "Smith", 42, false);

document.body.innerHTML += lucie.vratVypisCloveka() + "<br>";
document.body.innerHTML += pepa.vratVypisCloveka() + "<br>";

Clovek.svatba(pepa, lucie);
document.body.innerHTML += lucie.vratVypisCloveka() + "<br>";
